#
# spec file for package gource
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gource
Version:        0.54
Release:        1.6
Summary:        Software version control visualization tool
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Visualization/Graph
URL:            https://gource.io/
Source:         https://github.com/acaudwell/Gource/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  glm-devel >= 0.9.3
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
BuildRequires:  pkgconfig
BuildRequires:  tinyxml-devel
BuildRequires:  pkgconfig(SDL2_image) >= 2.0
BuildRequires:  pkgconfig(freetype2) >= 9.0.3
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libpng) >= 1.2
BuildRequires:  pkgconfig(sdl2) >= 2.0
Requires:       freefont

%description
Gource is a software version control visualization tool.

Software projects are displayed by Gource as an animated tree
with the root directory of the project at its centre. Directories
appear as branches with files as leaves. Developers can be seen
working on the tree at the times they contributed to the project.

Currently there is first party support for Git and Mercurial,
and third party (using additional steps) for CVS and SVN.

%prep
%setup -q

%build
%configure \
	--with-boost-libdir=%{_libdir} \
	--with-tinyxml=yes \
	--enable-ttf-font-dir=%{_datadir}/fonts/truetype
%make_build

%install
%make_install

%files
%doc ChangeLog README.md THANKS
%license COPYING
%{_mandir}/man1/*
%{_bindir}/gource
%{_datadir}/gource/

%changelog
* Mon Mar 13 2023 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 0.54:
  * Added experimental support for Wayland.
- Add new build dependency on libboost_system-devel.
* Tue Sep 27 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Pass --with-boost-libdir to configure: Workarounds boost
  detection failure on some architectures (ppc64, ppc64le and
  riscv64 notably) (gh#acaudwell/Gource#83).
* Thu Jun 16 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 0.53
  * Add --high-dpi option
  * Fixed slider timestamp font not affected by --font-scale
  * Fixed hovering over end of slider stopping time advancing
* Sat Apr  9 2022 ecsos <ecsos@opensuse.org>
- Update to 0.52
  * Support rendering at native resolution on Retina / Ultra HD displays.
  * Support ISO 8601 timestamp format.
  * Allow custom log and caption file timestamps to be strings.
  * Change regular expression library to PCRE2.
  * Fixed filenames not being affected by --font-scale (Carl Colena).
  * Fixed file key not being affected by --font-scale.
  * Added --file-idle-time-at-end option.
  * Added --fixed-user-size option.
* Wed Feb  5 2020 antoine.belvire@opensuse.org
- Update to version 0.51:
  * Fixed --font-file relative path handling.
  * Fixed a bug in resolving the repository root directory from a
    relative path.
- Changes from version 0.50:
  * Right mouse button rotation now pivots around the camera.
  * Added --font-file option.
  * Added --enable-font-file option to configure.
  * Added --no-time-travel option.
  * Added --dir-name-position option.
  * Added --file-extension-fallback option.
  * Added --user-show-filter option.
  * Added --disable-input option.
  * Added --loop-delay-seconds option.
  * Added --font-scale option.
  * Added filename, dirname and user font size options.
  * Added workaround for FFMpeg error parsing Gource PPM video
    output.
  * Fixed a bug in the Mercurial log parser that caused changes to
    be missed.
  * Fixed file removal being cancelled by an action with an earlier
    timestamp.
  * Fixed a bug in the log file format detection that could result
    in the wrong first entry being displayed for a custom log.
  * Fixed a bug where automatically cycling through a config with
    multiple repositories reset settings to their defaults.
- Remove obsolete conditional from spec file.
- Update URL.
* Mon Jul 16 2018 antoine.belvire@opensuse.org
- Update to version 0.49:
  * Fixed compatibility with GLM 0.9.9.0.
* Tue Jun 12 2018 antoine.belvire@opensuse.org
- Update to version 0.48:
  * Can now generate logs from git sub module directories.
  * Fixed building with GLM 0.9.9.
* Fri Nov 17 2017 astieger@suse.com
- gource 0.47:
  * Fix low mouse movement speed with some mice while repositioning
    camera
- includes changes from 0.46:
  * Add --screen option
- includes changes from 0.45:
  * Add --window-position XxY option
  * Add --frameless option
  * Add --file-show-filter REGEX option
  * Add --filename-time and filename-colour options
  * Improve handling of very low seconds-per-day values
  * Fix crash when SVN log lacks author information
  * Additional git log command validation
  * Allow lower case hex colours in custom logs
  * Now requires SDL 2 to build
* Thu Jul 13 2017 astieger@suse.com
- update to 0.44:
  * Fixed crash when taking a screenshot with an odd resolution
  * Fixed type deduction compilation error with newer versions of GCC
  * Documentation improvements
- drop svn-gource, gource has buil-t in svn support
- drop cvs-exp.pl
- drop gource-0.43-gcc6.patch, no longer required
- drop boost_ppc64le.patch, not being built for it
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Jul  2 2016 i@marguerite.su
- new patch: gource-0.43-gcc6.patch fixes boo#985356
  * fix no matching function for call to 'max(double,float)'
* Thu Aug 13 2015 dvaleev@suse.com
- Fix boost libdir on ppc64le (boost_ppc64le.patch)
* Tue Nov 11 2014 andreas.stieger@gmx.de
- gource 0.43:
  + Updated boost autoconf macros to fix multi-arch detection.
- includes changes from gource 0.42:
  + Fixed bzr log command when no start date was specified.
  + Fixed hg log commit order when date range specified.
  + Fixed hg log command line on Windows.
  + Fixed parser bug in date range filtering code.
- includes changes from gource 0.41:
  + Multi-monitor support using SDL 2.0 when available.
  + SDL 1.2 support is deprecated.
  + Full screen mode now uses desktop resolution by default.
  + Added --start-date, --stop-date 'YYYY-MM-DD hh:mm:ss' options.
  + Added --dir-name-depth option.
  + Changed --file-idle-time default value to 0.
  + Changed screenshot format to PNG.
- packaging changes:
  + update source URL
  + drop ppc64le.patch, upstream
  + update and clean up dependencies
  + build with and use system tinyxml library instead of in-tree
  + build with SDL2 where available
* Fri Jan 10 2014 dvaleev@suse.com
- Fix boot libdir for ppc64le
- added patches:
  * ppc64le.patch
* Mon Jul 22 2013 cfarrell@suse.com
- license update: GPL-3.0+
  No indication of licenses that would restrict the GPL-3.0 license to 3
  only
* Tue Jul  2 2013 dmitry_r@opensuse.org
- Update to version 0.40
  * Added caption support.
  * Improved command line interoperability on Windows.
  * Fixed directory deletion short circuiting processing
    the rest of a commit.
  * Fixed issue loading non-ascii user image filenames on windows.
  * Ignore UTF-8 byte order mark at the start of lines in custom
    log files.
  * Fix to boost macros for Macs and non-GNU systems (mistydemeo).
  * Autotools improvements (flameeyes).
* Tue Apr 23 2013 bruno@ioda-net.ch
- Added version dependency in spec libboost >= 1.46
- Added new dependency glm-devel > 0.9.3 (devel:library:c_c++)
- updated to 0.39
  Changes since 0.38:
    Fixed blurry non power of 2 logos.
    File colour changes now supported in custom logs (rmyorston).
    Fixed building against Boost 1.50 (svenstaro).
    Updated boost autoconf macros (flameeyes).
    Autogen script (matthiaskrgr).
  Changes since 0.37:
    New high quality sprites.
    Fullscreen toggle with alt + enter.
    Window is now resizable. -WIDTHxHEIGHT! creates a non-resizable window.
    Lowered minimum zoom distance.
    Use AM_CPPFLAGS in Makefile.am to allow passing custom CPPFLAGS.
    Don't add files that match the path of a known directory.
    Fixed divide by zero in text shader causing artifacts on some video cards.
    Recursively search for repository directory when log-format not specified (thanks to Jörg Bachmann for original concept / prototype).
    New dependency on Boost Filesystem.
    Doubled the maximum zoom out distance.
    Allow negative timestamps before 1970 in custom log (artzub).
    Fix for UTF8-CPP checked.h compilation issue (vszakats).
    Fixed bug causing missing characters in text.
    Fixed --highlight-users option not using highlight-colour.
    highlight-colour default changed to white.
    Added --selection-colour option (applied to selected users and files).
    Added --dir-colour option (applied to directories).
  There are some new dependencies for building this version:
    GLM 0.9.3 (header only library)
    Boost Filesystem >= 1.46
* Fri Nov 11 2011 prusnak@opensuse.org
- updated to 0.37
- drop obsolete patch nonvoid.patch (applied upstream)
* Fri May 27 2011 prusnak@opensuse.org
- merge package from Contrib
- updated to version 0.34
- added two extra tools
* Wed Apr 13 2011 asn@cryptomilk.org
- update to version 0.32
  * Fixed behaviour of user camera tracking.
  * Added --with-tinyxml option to configure (use the system TinyXML library).
  * Fixed crash when SVN log entry contains no 'paths' element.
  * Handle directory deletion (happens in SVN logs).
* Tue Feb  8 2011 asn@cryptomilk.org
- update to version 0.29
  * SVN built-in support.
  * cvs2cl log support (cvs-exp support is now deprecated).
  * Made camera behaviour when zooming and selecting objects more
    intuitive.
  * Improved interactive performance.
  * Added file extension key (--key or toggled with 'K').
  * Added mouse-over tool tips.
  * Added --highlight-colour option.
  * Added --hash-seed option. The S key now randomizes colours.
  * Added --output-custom-log option.
  * Exposed --time-scale option (previously only available
    interactively).
  * Removed arbitrary 1024 maximum length limit for log lines.
  * Fixed two file colouring bugs (quoted files from git, period in
    file path).
  * Fix handling of avatars for UTF-8 usernames on MACOSX.
  * Recover from video mode failing to set due to multi-sampling.
- update to version 0.28
  * Bazaar support for merged commits (Nick Moffit).
  * C++ efficiency improvements (Oliver Smith).
  * Improved cvs-exp log compatibility.
  * Re-show name of user when adding a new action if user is idle.
  * Added --padding option to control camera view padding.
  * More accurate camera tracking (tracks the bounding boxes of
    objects).
  * Improved automatic rotation logic.
- update to version 0.27
  * Config file support (ini style .conf files) has been added. You
    can convert a gource command line to a conf file with
  - -save-config CONF_FILE.
  * Automatic camera rotation has been added which makes better use
    of the screen space.
  * Support for logos, titles and background images to brand your
    gource videos.
  * Take tga screenshots with F12. Combined with the --transparent
    option you can can use this to make gource decals.
* Tue Apr 13 2010 pascal.bleser@opensuse.org
- update to 0.26a:
  * updated to latest version of GL autoconf macros.
* Fri Apr  2 2010 bitshuffler #suse@irc.freenode.org
- Updated to 0.26
* Sat Dec  5 2009 pascal.bleser@opensuse.org
- initial version (0.18)
